@@ -1,9 +1,10 @@
-syntab <- function (veg, clust, type = c('rel','abs','mean.cover'), fullnames=FALSE, limit=0, mupa=FALSE, alpha=0.05, minstat=0, dec = 0, ...)
+syntab <- function (veg, clust, type = c('rel','abs','mean.cover'), fullnames=FALSE, limit=0, mupa=NULL, alpha=0.05, minstat=0, dec = 0, ...)
 {
+#    if(mupa & !'indicspecies' %in% installed.packages()[,1]) stop('Please install package \'indicspecies\' before using option mupa=TRUE')
     type <- match.arg(type)
     if (missing(clust)) clust <- rep(1,nrow(veg))
     ncl <- length(unique(clust))
-    if(type=='assoc') mupa=TRUE
+    if(type=='assoc') mupa = TRUE
     cat(' Number of clusters: ', ncl, '\n')
     cat('Cluster frequency', as.vector(table(clust)),'\n')
     sp.veg <- split(veg, clust)
@@ -24,9 +25,9 @@ syntab <- function (veg, clust, type = c('rel','abs','mean.cover'), fullnames=FA
     st <- as.data.frame(temp)
     st[is.na(st)] <- 0
     names(st) <- levels(clust)
-    if(ncl>1) st <- st[apply(st, 1, function(x) max(x, na.rm=TRUE)>limit),]
+    if(ncl>1) st <- st[apply(st, 1, function(x) max(x, na.rm=TRUE) > limit),]
 
-    if(mupa | class(mupa)=='multipatt' & ncl<1) {
+    if(!is.null(mupa) | class(mupa)=='multipatt' & ncl<1) {
       require(indicspecies)
       if(class(mupa)!='multipatt')
 	mu <- multipatt(veg, clust, ...) else 
@@ -37,25 +38,28 @@ syntab <- function (veg, clust, type = c('rel','abs','mean.cover'), fullnames=FA
 
       st <- st[o,]
       st$cl <- attr(mu$str,'dimnames')[[2]][sig[o,'index']]
-      class(st) <- c('syntab','data.frame')
     }
+    class(st) <- c('syntab','data.frame')
 
     if(fullnames) {
       nam <- tax(rownames(st), tax=FALSE, ...)
       rownames(st) <- nam$ABBREVIAT[match(rownames(st), nam$LETTERCODE)]
       }
-    return(st)
+    print(st)
+    invisible(st)
 }
 
 print.syntab <- function(x, zero.print='.', ...) {
 class(x) <- 'data.frame'
-if(names(x)[ncol(x)] == 'cl') mu=TRUE
-if(mu) {cl <- x[ncol(x)]; x <- x[-ncol(x)]}
+if(ncol(x)>1) {
+  if(names(x)[ncol(x)] == 'cl') mu=TRUE else mu=FALSE
+  if(mu) {cl <- x[ncol(x)]; x <- x[-ncol(x)]}
    if(zero.print != "0" && any(i0 <- x == 0)) {
       x[i0] <- sub("0", zero.print, x[i0])
       x[i0] <- sub("0.0", zero.print, x[i0])
       x[i0] <- sub("0.00", zero.print, x[i0]) }
-if(mu) x <- cbind(x, cl)
-    print.data.frame(x, zero.print='', ...)
-  }
+  if(mu) x <- cbind(x, cl)
+ }
+   print.data.frame(x, zero.print='', ...)
+ }
 
